/*
 * SSD2805_S6D04D2.h
 *
 *  Created on: May 08, 2014
 *      Author: John Leung
 */

#ifndef SSD2805_S6D04D2_H_
#define SSD2805_S6D04D2_H_

#include <stdint.h>
#include <stdbool.h>
#include <stddef.h>
#include "driverlib/debug.h"
#include "inc/hw_gpio.h"
#include "inc/hw_ints.h"
#include "inc/hw_memmap.h"
#include "inc/hw_types.h"
#include "driverlib/gpio.h"
#include "inc/hw_gpio.h"
#include "driverlib/interrupt.h"
#include "driverlib/sysctl.h"
#include "driverlib/timer.h"
#include "driverlib/rom.h"
#include "grlib/grlib.h"

#define DelayMs(ulClockMS) {ROM_SysCtlDelay(ulClockMS*(SysCtlClockGet() / (3 * 1000)));}

//physical dimension of the display
#define DISP_HOR_RESOLUTION	240
#define DISP_VER_RESOLUTION 240

#define MASK 0xff00ff

typedef union
{
    uint16_t Val;
    uint8_t v[2];
}uint16_val;

typedef	uint16_t  GFX_COLOR;

//5-6-5 16-bit color
#define RGBConvert(red, green, blue)    (GFX_COLOR) ((((GFX_COLOR)(red) & 0xF8) << 8) | (((GFX_COLOR)(green) & 0xFC) << 3) | ((GFX_COLOR)(blue) >> 3))

#ifndef BLACK
	#define BLACK           RGBConvert(0, 0, 0)
#endif
#ifndef BRIGHTBLUE
	#define BRIGHTBLUE      RGBConvert(0, 0, 255)
#endif
#ifndef BRIGHTGREEN
	#define BRIGHTGREEN     RGBConvert(0, 255, 0)
#endif
#ifndef BRIGHTCYAN
	#define BRIGHTCYAN      RGBConvert(0, 255, 255)
#endif
#ifndef BRIGHTRED
	#define BRIGHTRED       RGBConvert(255, 0, 0)
#endif
#ifndef BRIGHTMAGENTA
	#define BRIGHTMAGENTA   RGBConvert(255, 0, 255)
#endif
#ifndef YELLOW
	#define YELLOW          RGBConvert(255, 255, 128)
#endif
#ifndef BRIGHTYELLOW
	#define BRIGHTYELLOW    RGBConvert(255, 255, 0)
#endif
#ifndef LIGHTYELLOW
	#define LIGHTYELLOW     RGBConvert(255, 255, 150)
#endif
#ifndef GOLD
	#define GOLD            RGBConvert(255, 215, 0)
#endif
#ifndef BLUE
	#define BLUE            RGBConvert(0, 0, 128)
#endif
#ifndef GREEN
	#define GREEN           RGBConvert(0, 128, 0)
#endif
#ifndef CYAN
	#define CYAN            RGBConvert(0, 128, 128)
#endif
#ifndef RED
	#define RED             RGBConvert(128, 0, 0)
#endif
#ifndef MAGENTA
	#define MAGENTA         RGBConvert(128, 0, 128)
#endif
#ifndef BROWN
	#define BROWN           RGBConvert(255, 128, 0)
#endif
#ifndef LIGHTGRAY
	#define LIGHTGRAY       RGBConvert(128, 128, 128)
#endif
#ifndef DARKGRAY
	#define DARKGRAY        RGBConvert(64, 64, 64)
#endif
#ifndef LIGHTBLUE
	#define LIGHTBLUE       RGBConvert(128, 128, 255)
#endif
#ifndef LIGHTGREEN
	#define LIGHTGREEN      RGBConvert(128, 255, 128)
#endif
#ifndef LIGHTCYAN
	#define LIGHTCYAN       RGBConvert(128, 255, 255)
#endif
#ifndef LIGHTRED
	#define LIGHTRED        RGBConvert(255, 128, 128)
#endif
#ifndef LIGHTMAGENTA
	#define LIGHTMAGENTA    RGBConvert(255, 128, 255)
#endif
#ifndef WHITE
	#define WHITE           RGBConvert(255, 255, 255)
#endif
#ifndef SADDLEBROWN
	#define SADDLEBROWN 	RGBConvert(139, 69, 19)
#endif
#ifndef SIENNA
	#define SIENNA      	RGBConvert(160, 82, 45)
#endif
#ifndef PERU
	#define PERU        	RGBConvert(205, 133, 63)
#endif
#ifndef BURLYWOOD
	#define BURLYWOOD  	 	RGBConvert(222, 184, 135)
#endif
#ifndef WHEAT
	#define WHEAT       	RGBConvert(245, 245, 220)
#endif
#ifndef TAN
	#define TAN         	RGBConvert(210, 180, 140)
#endif
#ifndef ORANGE
	#define ORANGE         	RGBConvert(255, 187, 76)
#endif
#ifndef DARKORANGE
	#define DARKORANGE      RGBConvert(255, 140, 0)
#endif
#ifndef LIGHTORANGE
	#define LIGHTORANGE     RGBConvert(255, 200, 0)
#endif
#ifndef GRAY242
	#define GRAY242      	RGBConvert(242, 242, 242)
#endif
#ifndef GRAY229
	#define GRAY229      	RGBConvert(229, 229, 229)
#endif
#ifndef GRAY224
	#define GRAY224         RGBConvert(224, 224, 224)
#endif
#ifndef GRAY204
	#define GRAY204      	RGBConvert(204, 204, 204)
#endif
#ifndef GRAY192
	#define GRAY192         RGBConvert(192, 192, 192)
#endif
#ifndef GRAY160
	#define GRAY160         RGBConvert(160, 160, 160)
#endif
#ifndef GRAY128
	#define GRAY128         RGBConvert(128, 128, 128)
#endif
#ifndef GRAY096
	#define GRAY096          RGBConvert(96, 96, 96)
#endif
#ifndef GRAY032
	#define GRAY032          RGBConvert(32, 32, 32)
#endif
#ifndef GRAY010
	#define GRAY010          RGBConvert(10, 10, 10)
#endif

#define MAX(a, b) (((a) > (b)) ? (a) : (b))
#define MIN(a, b) (((a) > (b)) ? (b) : (a))

//*****************************************************************************
//
// Translates a 24-bit RGB color to a display driver-specific color.
//
// \param c is the 24-bit RGB color.  The least-significant byte is the blue
// channel, the next byte is the green channel, and the third byte is the red
// channel.
//
// This macro translates a 24-bit RGB color into a value that can be written
// into the display's frame buffer in order to reproduce that color, or the
// closest possible approximation of that color.
//
// \return Returns the display-driver specific color.
//
// 24-bit format: XXXX XXXX RRRR RRRR GGGG GGGG BBBB BBBB
// 16-bit format: ---- ---- ---- ---- RRRR RGGG GGGB BBBB
//  8-bit format: ---- ---- ---- ---- ---- ---- RRRG GGBB
//
//
//*****************************************************************************

//RGBConvert(red, green, blue)    (GFX_COLOR) ((((GFX_COLOR)(red) & 0xF8) << 8) | (((GFX_COLOR)(green) & 0xFC) << 3) | ((GFX_COLOR)(blue) >> 3))
/*
#define DPYCOLORTRANSLATE16(c)  ((((c) & 0x00f80000) >> 8) |                  \
                                 (((c) & 0x0000fc00) >> 5) |                  \
                                 (((c) & 0x000000f8) >> 3))

*/
#define DPYCOLORTRANSLATE16(c)  ((((c) & 0x00f80000) >> 8) |                  \
                                 (((c) & 0x0000fc00) >> 5) |                  \
                                 (((c) & 0x000000f8) >> 3))
#define DPYCOLORTRANSLATE8(c)   ((((c) & 0x00e00000) >> 16) |                 \
                                 (((c) & 0x0000e000) >> 11) |                 \
                                 (((c) & 0x000000c0) >> 6))
#define DPYCOLORTRANSLATE DPYCOLORTRANSLATE16


#define LCD_DATAH_PERIPH        SYSCTL_PERIPH_GPIOB
#define LCD_DATAH_BASE          GPIO_PORTB_BASE
#define LCD_DATAH_PINS          0xff


//something special for SSD2805. This is TX_CLK generated by the MPU with PWM to 20MHz
#define LCD_TXCLK_FREQ			20000000UL	//20MHz
#define LCD_TXCLK_PERIPH		SYSCTL_PERIPH_GPIOF	//TX_CLK input (20MHz clock input) = PF3
#define LCD_TXCLK_BASE			GPIO_PORTF_BASE		//Clock input for SSD2805 is generated by PWM of TM4C MCU
#define LCD_TXCLK_PIN			GPIO_PIN_3
#define LCD_TXCLK_PIN_MUX		GPIO_PF3_M1PWM7		//alternate function of a GPIO pin to be configured, for this it is a PWM
#define LCD_TXCLK_PWMMOD		SYSCTL_PERIPH_PWM1	//PWM module 1 (PF3) for TX_CLK output
#define LCD_TXCLK_PWM_BASE		PWM1_BASE			//base address of the PWM module
#define LCD_TXCLK_PWM_GEN		PWM_GEN_3			//PWM generator to configure
#define LCD_TXCLK_PWM_OUT		PWM_OUT_7			//PWM output to modify
#define LCD_TXCLK_PWM_BIT		PWM_OUT_7_BIT		//logical OR bit
//
// LCD control line GPIO definitions.
//
#define LCD_CS_PERIPH           SYSCTL_PERIPH_GPIOA	//CS = PA6
#define LCD_CS_BASE             GPIO_PORTA_BASE
#define LCD_CS_PIN              GPIO_PIN_6

#define LCD_DC_PERIPH           SYSCTL_PERIPH_GPIOA	//DC = PA2
#define LCD_DC_BASE             GPIO_PORTA_BASE
#define LCD_DC_PIN              GPIO_PIN_2

#define LCD_WR_PERIPH           SYSCTL_PERIPH_GPIOA	//WR = PA3
#define LCD_WR_BASE             GPIO_PORTA_BASE
#define LCD_WR_PIN              GPIO_PIN_3

#define LCD_RD_PERIPH           SYSCTL_PERIPH_GPIOA	//RD = PA4
#define LCD_RD_BASE             GPIO_PORTA_BASE
#define LCD_RD_PIN              GPIO_PIN_4

#define LCD_RST_PERIPH          SYSCTL_PERIPH_GPIOA	//RST = PA7
#define LCD_RST_BASE            GPIO_PORTA_BASE
#define LCD_RST_PIN             GPIO_PIN_7

#define LCD_BACKLIGHT_PERIPH    SYSCTL_PERIPH_GPIOD	//Backlight = PD1
#define LCD_BACKLIGHT_BASE      GPIO_PORTD_BASE
#define LCD_BACKLIGHT_PIN       GPIO_PIN_1

//Peripheral definitions
#define VIBRATE_PERIPH			SYSCTL_PERIPH_GPIOD	//vibration pin PD0 connected to motor control
#define VIBRATE_BASE      		GPIO_PORTD_BASE
#define VIBRATE_PIN       		GPIO_PIN_6

#define DisplayVibrationConfig()	{ROM_SysCtlPeripheralEnable(VIBRATE_PERIPH);	ROM_GPIOPinTypeGPIOOutput(VIBRATE_BASE, VIBRATE_PIN);}
#define DisplayVibrationOff()		HWREG(VIBRATE_BASE + GPIO_O_DATA + ( VIBRATE_PIN << 2)) = 0;
#define DisplayVibrationOn()		HWREG(VIBRATE_BASE + GPIO_O_DATA + ( VIBRATE_PIN << 2)) = VIBRATE_PIN;
//

#define DisplayDataConfig()			{SysCtlPeripheralEnable(LCD_DATAH_PERIPH);		GPIOPinTypeGPIOOutput(LCD_DATAH_BASE, LCD_DATAH_PINS);}
#define DisplayCmdDataConfig()		{SysCtlPeripheralEnable(LCD_DC_PERIPH);			GPIOPinTypeGPIOOutput(LCD_DC_BASE, LCD_DC_PIN);}
#define DisplayConfig()				{SysCtlPeripheralEnable(LCD_CS_PERIPH);			GPIOPinTypeGPIOOutput(LCD_CS_BASE, LCD_CS_PIN);}
#define DisplayResetConfig()		{SysCtlPeripheralEnable(LCD_RST_PERIPH);		GPIOPinTypeGPIOOutput(LCD_RST_BASE, LCD_RST_PIN);}
#define DisplayWriteConfig()		{SysCtlPeripheralEnable(LCD_WR_PERIPH);			GPIOPinTypeGPIOOutput(LCD_WR_BASE, LCD_WR_PIN);}
#define DisplayReadConfig()			{SysCtlPeripheralEnable(LCD_RD_PERIPH);			GPIOPinTypeGPIOOutput(LCD_RD_BASE, LCD_RD_PIN);}
#define DisplayBacklightConfig()	{SysCtlPeripheralEnable(LCD_BACKLIGHT_PERIPH);	GPIOPinTypeGPIOOutput(LCD_BACKLIGHT_BASE, LCD_BACKLIGHT_PIN);}

#define DisplayDisable()			HWREG(LCD_CS_BASE + GPIO_O_DATA + (LCD_CS_PIN << 2)) = LCD_CS_PIN;	//CS# high
#define DisplayEnable()				HWREG(LCD_CS_BASE + GPIO_O_DATA + (LCD_CS_PIN << 2)) = 0;			//CS# low

#define DisplayWriteDisable()		HWREG(LCD_WR_BASE + GPIO_O_DATA + (LCD_WR_PIN << 2)) = LCD_WR_PIN;	//WR# high
#define DisplayWriteEnable()		HWREG(LCD_WR_BASE + GPIO_O_DATA + (LCD_WR_PIN << 2)) = 0;			//WR# low

#define DisplayReadDisable()		HWREG(LCD_RD_BASE + GPIO_O_DATA + (LCD_RD_PIN << 2)) = LCD_RD_PIN;	//RD# high
#define DisplayReadEnable()			HWREG(LCD_RD_BASE + GPIO_O_DATA + (LCD_RD_PIN << 2)) = 0;			//RD# low

#define DisplayResetDisable()		HWREG(LCD_RST_BASE + GPIO_O_DATA + (LCD_RST_PIN << 2)) = LCD_RST_PIN;	//RST# high
#define DisplayResetEnable()		HWREG(LCD_RST_BASE + GPIO_O_DATA + (LCD_RST_PIN << 2)) = 0;				//RST# low

#define DisplayBacklightOff()		HWREG(LCD_BACKLIGHT_BASE + GPIO_O_DATA + (LCD_BACKLIGHT_PIN << 2)) = 0;					//BACKLIGHT SHDN low
#define DisplayBacklightOn()		HWREG(LCD_BACKLIGHT_BASE + GPIO_O_DATA + (LCD_BACKLIGHT_PIN << 2)) = LCD_BACKLIGHT_PIN;	//BACKLIGHT SHDN high

#define DisplaySetData()			HWREG(LCD_DC_BASE + GPIO_O_DATA + (LCD_DC_PIN << 2)) = LCD_DC_PIN;	//DC pin high for data
#define DisplaySetCommand()			HWREG(LCD_DC_BASE + GPIO_O_DATA + (LCD_DC_PIN << 2)) = 0;			//DC pin set low for command

#define DisplayWrite(ui8Data)		{	HWREG(LCD_DATAH_BASE + GPIO_O_DATA + (LCD_DATAH_PINS << 2)) = (ui8Data);\
										DisplayWriteEnable(); DisplayWriteDisable();}

//important!!! SSD2805 get lower byte first in 16-bit data
//
#define DisplayWrite16(ui16Data)	{	HWREG(LCD_DATAH_BASE + GPIO_O_DATA + (LCD_DATAH_PINS << 2)) = (uint8_t)(ui16Data&0x00ff);\
										DisplayWriteEnable();DisplayWriteDisable();\
										HWREG(LCD_DATAH_BASE + GPIO_O_DATA + (LCD_DATAH_PINS << 2)) = (uint8_t)(ui16Data>>8);\
										DisplayWriteEnable();DisplayWriteDisable();}

extern void DisplayPutImage(int32_t i32X, int32_t i32Y, const uint8_t *pui8Data);

extern void DisplayReset(void);
extern void DisplayClearDevice(GFX_COLOR color);
extern void DisplayRectFill(uint16_t left, uint16_t top, uint16_t right, uint16_t bottom, uint32_t ui32Value);
extern void DisplayOn(void);
extern void DisplayOff(void);
extern void DisplaySleepIn(void);
extern void DisplaySleepOut(void);
extern void DisplayIdleOn(void);
extern void DisplayIdleOff(void);
extern void DisplayPutPixel(int16_t x, int16_t y, GFX_COLOR color);
extern void DisplaySoftReset(void);
extern void DisplayBackgroundSet(uint32_t ui32Color);
extern uint32_t DisplayBackgroundGet(void);
extern void DisplayForegroundSet(uint32_t ui32Color);
extern uint32_t ForeBackgroundGet(void);
extern void DisplayLineDrawV (int32_t i32X, int32_t i32Y1, int32_t i32Y2, uint32_t ui32Value);
extern void DisplayLineDrawH (int32_t i32X1, int32_t i32X2, int32_t i32Y, uint32_t ui32Value);


extern const tDisplay g_DisplaySolomonSSD2805;

/*
 * ***************************************************************************************
 * Display Command Set (DCS) is a set of common commands for controlling
 * the display device in compliance with the DSI standard. Each command
 * is an eight-bit code with 00h to AFh assigned to the User Command Set
 * and all other codes assigned to the Manufacturer Command Set.
 * DCS defined here with prefix DCS_ and MCS with MCS_
 * ***************************************************************************************
 */
#define DCS_NOP                 0x00	//no operation. This is an empty command
#define DCS_SWRESET             0x01    //soft reset
#define DCS_RDNUMED				0x05	//read number of errors on DSI
#define DCS_RDDPM               0x0A    //Read display power mode
#define DCS_RDDMADCTL           0x0B    //Read display MADCTL for column address order, RGB/BGR order etc
#define DCS_RDDCOLMOD           0x0C    //Read display display pixel format
#define DCS_RDDIM               0x0D    //Read display image mode
#define DCS_RDDSM               0x0E    //Read display signal mode
#define DCS_RDDSDR              0x0F    //Read display self-diagnostic result
#define DCS_SLPIN               0x10	//sleep in command to enter the min. power mode
#define DCS_SLPOUT              0x11	//sleep out command to turn off sleep mode
#define DCS_NORON               0x13    //Normal display mode on
#define DCS_INVOFF              0x20	//Display inversion off
#define DCS_INVON               0x21	//Display inversion on
#define DCS_DISPOFF             0x28	//Display off with a blank page inserted. No change of frame memory content
#define DCS_DISPON              0x29	//Display on to recover from Display Off Mode

#define DCS_CASET	            0x2A	//Column Address Set to define area of frame memory where MPU can access
										//Parameters are inclusive, that means from SC[15:0] = 0 to EC[15:0] = 239
										//for the panel resolution of 240 pixels in width
#define DCS_PASET               0x2B	//Page Address Set, similar to DCS_CASET, this command for SP[15:0] and EP[15:0]

#define DCS_RAMWR               0x2C    //command to transfer data from MPU to frame memory
										//It is important to note that when this command is accepted, the column &
										//page registers are reset to the Start Column/Start Page defined in DCS_CASET &
										//DCS_PASET

#define DCS_RAMRD               0x2E	//This command is used to transfer data from display's frame memory back to MPU.
										//When this command is accepted, the column & page registers are reset to the Start
										//Column.Start Page defined in DCS_CASET & DCS_PASET

#define DCS_TEOFF               0x34	//Tearing effect line OFF

#define DCS_TEON                0x35	//Tearing effect line ON

#define DCS_MADCTL         		0x36    //memory access control for frame buffer scanning direction etc
#define DCS_IDMOFF      		0x38	//This command is used to recover from idle mode on
#define DCS_IDMON		        0x39	//This command is used to enter into idle mode to reduce to 8 color depth
#define DCS_COLMOD              0x3A    //interface pixel format set
#define DCS_RAMWRC              0x3C    //This command continues writing to memory after DCS_RAMWR. When this command
										//is accepted, no column/page registers are reset. This command is good for
										//writing data to frame memory in block for speed optimization
#define DCS_RAMRDC			    0x3E	//Counterpart for DCS_RAMWRC to "block read" from frame memory to MPU
#define DCS_RDDDBS				0xA1	//Returns supplier ID
#define DCS_RDDDBC				0xA8	//continue reading supplier's ID after DCS_RDDDBS has been interrupted

//SSD2805 specific registers
#define MCS_CFGR				0xB7	//configuration register
#define MCS_VCR					0xB8	//VC control register to set virtual channel
#define MCS_PCR					0xB9	//PLL control register
#define MCS_PLCR				0xBA	//PLL config register
#define MCS_CCR					0xBB	//Clock control register

#define MCS_PSCR1				0xBC	//Packet size control register 1, specifies the total number of data bytes (in byte)
										//to be transmitted by SSD2805 in the next operation.
#define MCS_PSCR2				0xBD	//Packet size control register 2
#define MCS_PSCR3				0xBE	//Packet size threshold, min=2, max=0x400

#define MCS_TR					0xD6	//Test register

/*

static  void DisplayPutImage8BPP(int32_t i32X, int32_t i32Y, const uint8_t *pui8Data)
{
	uint8_t *pui8Palette;				//pointer to palette data
	uint16_t ui16SizeX, ui16SizeY;		//size of picture in ui16X * ui16Y
	uint8_t ui8PaletteEntry;			//maximum color index in palette (index starts from 0)
	uint32_t ui32PixelCount;
	uint32_t ui32PixelData;				//it is actually the palette entry in 24-bit for 8BPP
	uint16_t x,y;

	if((i32X > (DISP_HOR_RESOLUTION-1)) || (i32Y > (DISP_VER_RESOLUTION-1)) ) return;

	if(*((uint8_t *)pui8Data)!=IMAGE_FMT_8BPP_UNCOMP) return;	//just for uncompressed 8BPP for this
	pui8Data++;

	ui16SizeX = *((uint16_t *)pui8Data);
	pui8Data +=2;
	ui16SizeY = *((uint16_t *)pui8Data);
	pui8Data +=2;

	ui8PaletteEntry=  *((uint8_t *)pui8Data);
	pui8Data++;

	pui8Palette = (uint8_t *)pui8Data;			//initialize pointer to start of palette

	pui8Data += (ui8PaletteEntry+1)*3;			//increment address to start of pixel

	ui32PixelCount = (uint32_t)ui16SizeX*ui16SizeY;


		if((i32X+ui16SizeX > DISP_HOR_RESOLUTION) || (i32Y+ui16SizeY > DISP_VER_RESOLUTION))
		{
			//clipping handled here
			for(y=0; y < ui16SizeY; y++)
			{
				if((i32Y+y)>DISP_VER_RESOLUTION) return;	//image out of display area

				DisplaySetAddressRect(i32X, i32Y+y, DISP_HOR_RESOLUTION-1, DISP_VER_RESOLUTION-1);

				SSD2805WriteTDCSize((DISP_HOR_RESOLUTION-i32X)*2);	//*2 required for 16-bit BPP

			    DisplayEnable();
				DisplaySetCommand();
				DisplayWrite(DCS_RAMWR);
				DisplaySetData();
				for(x=0; x<ui16SizeX; x++)
				{
		            // Get the next byte of pixel data and extract the
		            // corresponding entry from the palette.
					ui32PixelData = (*pui8Data++)*3;
					ui32PixelData = *(uint32_t *)(pui8Palette + ui32PixelData);
					if((i32X+x)<DISP_HOR_RESOLUTION)
					{
						// Translate this palette entry and write it to the screen.
						DisplayWrite16((uint16_t)DPYCOLORTRANSLATE(ui32PixelData));
					}
				}
				DisplayDisable();
			}
		}
		else
		{
			//whole image within screen boundary, optimized write possible here
			//define area of writing rectangle
			DisplaySetAddressRect((uint16_t)i32X,(uint16_t)i32Y, MIN(i32X+ui16SizeX-1,DISP_HOR_RESOLUTION-1), MIN(i32Y+ui16SizeY-1,DISP_VER_RESOLUTION-1));

			SSD2805WriteTDCSize(0);
		    DisplayWriteReg(DCS_RAMWR, 0x0000);		//dummy write to reset Column and Page addresses

			//It is important to notice that, pixel format is NOT equivalent to data bus width
			//Data bus width in Tiva C EVK is in 8-bit width DATA[7:0] interfacing SSD2805 D[7:0].
			//However, pixel format represents the bit-per-pixel format in color space
			//In this case, the byte count = pixel count *2 since bit-per-pixel = 16BPP with 8-bit interface (hardware) and the
			//number of byte transmitted is therefore pixel count *2
		    SSD2805WriteTDCSize(ui32PixelCount*2);

		    DisplayEnable();
			DisplaySetCommand();
			DisplayWrite(DCS_RAMWRC);
			DisplaySetData();
		    //block write data to TFT
			while(ui32PixelCount--)
			{
	            // Get the next byte of pixel data and extract the
	            // corresponding entry from the palette.
				ui32PixelData = *pui8Data++*3;
				ui32PixelData = *(uint32_t *)(pui8Palette + ui32PixelData);
	            // Translate this palette entry and write it to the screen.
				DisplayWrite16((uint16_t)DPYCOLORTRANSLATE(ui32PixelData));

			}
			DisplayDisable();
		}

}

 */
#endif /* SSD1268_H_ */
